/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.notification.actions.impl;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import org.ow2.jasmine.event.beans.JasmineEventNotification;
import org.ow2.jasmine.monitoring.eos.notification.actions.api.AbstractFileDownloadAction;
import org.ow2.jasmine.monitoring.eos.notification.actions.exchange.ActionResult;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * @author Guillaume Renault
 */
public class FileDownloadExampleAction extends AbstractFileDownloadAction {

    private static final String NAME = "FileDownloadExampleAction";

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(FileDownloadExampleAction.class);

    /**
     * Temporary directory where files are stored
     */
    private final String tempDir = System.getProperty("java.io.tmpdir") + File.separatorChar + "EoS.temp" + File.separatorChar;

    /**
     * Execute the action.
     */
    @Override
    public ActionResult execute(final JasmineEventNotification notification) {



        File file = new File(tempDir, "test.txt");

        try {
            File tmpDir = new File(tempDir);
            tmpDir.mkdir();

            file.createNewFile();
            FileWriter fw = new FileWriter(file);

            fw.write("This text is the test ...");
            fw.close();

        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }

        logger.debug("Download the file {0}", file.getAbsolutePath());

        ActionResult result = new ActionResult();
        result.setResult(file.getAbsolutePath());
        result.setType(this.getType());

        return result;
    }

    /**
     * Get the name of the action.
     *
     * @return the name of the action.
     */
    @Override
    public String getName() {
        return NAME;
    }

}
